%define libname linphone-libs
%define devname linphone-devel
%define libnamepp %{name}-c++-libs

%bcond_without docs
%bcond_without linphonepp

Summary:        Voice over IP Application
Name:           liblinphone
Version:        5.3.84
Release:        1%{?dist}.inferit

License:        GPLv2+
URL:            https://www.linphone.org/
Source0:       	https://gitlab.linphone.org/BC/public/liblinphone/-/archive/%{version}/liblinphone-%{version}.tar.gz
Patch0:         0001-Use-system-CA-Bundle.patch
Patch1:         linphone-cmake-config-location.patch
Patch2:         liblinphone-system-xsd.patch
Patch3:         liblinphone-jsoncpp-dep.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  ninja-build
BuildRequires:  doxygen graphviz
BuildRequires:  ffmpeg-devel
BuildRequires:  gsm-devel
BuildRequires:  readline-devel
BuildRequires:  vim-common
BuildRequires:  python3-pystache
BuildRequires:  python3-six
BuildRequires:  soci-mysql-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  turbojpeg-devel
BuildRequires:  xsd-devel
BuildRequires:  cmake(Mediastreamer2)
BuildRequires:  cmake(BCToolbox)
BuildRequires:  cmake(BelCard)
BuildRequires:  cmake(BelleSIP)
BuildRequires:  cmake(Ortp)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libosip2)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libupnp) >= 1.6
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(spandsp)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(zxing)
BuildRequires:  belle-sip-devel
BuildRequires:  gcc-c++

%description
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

%package -n linphone-cli
Summary:        Command Line Interface for %{name}
Requires:       liblinphone-data >= %{version}-%{release}
Conflicts:      linphone < 3.12.0-2

%description -n linphone-cli
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains the command line interface.

%package -n linphone-daemon
Summary:        Daemonfor %{name}
Requires:       liblinphone-data >= %{version}-%{release}
Conflicts:      linphone < 3.12.0-2
Conflicts:      linphone-cli < 5.3.5

%description -n linphone-daemon
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains the daemon.

%package data
Summary:        Data files for %{name}
BuildArch:      noarch
Conflicts:      linphone < 3.12.0-2

%description data
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains data files such as sounds.

%package -n %{libname}
Summary:        Primary library for %{name}
Requires:       liblinphone-data >= %{version}-%{release}
Requires:       soci-sqlite3%{_isa}
Requires:       soci-mysql%{_isa}

%description -n %{libname}
Primary library for %{name}.

%package -n %{libnamepp}
Summary:        C++ wrapper library for %{name}

%description -n %{libnamepp}
C++ wrapper library for %{name}.

%package -n %{devname}
Summary:        Header files and development libraries from %{name}
Requires:       %{libname} = %{version}-%{release}
%if %{with linphonepp}
Requires:       %{libnamepp} = %{version}-%{release}
%endif
Requires:       %{name}-data >= %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      linphone < 3.12.0

%description -n %{devname}
Libraries and includes files for developing programs based on %{name}.

%prep
%setup -q
%autopatch -p1

find '(' -name '*.c' -o -name '*.h' ')' -print0 | xargs -0 sed -i -e 's,\r$,,'

# Fix version
sed -i -e '/project/s/\(VERSION\)\s\+"*[0-9]\+\(\.[0-9]\+\)\+"*/\1 "%{version}"/' CMakeLists.txt

# Drop bundled xsd
rm -rf libxsd

# Fix XSD runtime version mismatch
sed -i -e '/XSD_INT_VERSION/s/!=/</g' $(grep -r -l XSD_INT_VERSION)

%build
%global build_cxxflags %optflags -fpermissive
%cmake -GNinja \
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES \
    -DENABLE_CONSOLE_UI:BOOL=YES \
    -DENABLE_DAEMON:BOOL=YES \
    -DENABLE_STATIC:BOOL=NO \
    -DENABLE_ROOTCA_DOWNLOAD:BOOL=NO \
    -DENABLE_GTK_UI:BOOL=NO \
    -DENABLE_TOOLS:BOOL=NO \
    -DENABLE_STRICT:BOOL=NO \
    -DENABLE_UNIT_TESTS:BOOL=NO \
    -DENABLE_DB_STORAGE:BOOL=YES \
    -DENABLE_LIME_X3DH:BOOL=NO \
    -DENABLE_DOC:BOOL=%{?with_docs:YES}%{?!with_docs:NO} \
    -DENABLE_CXX_WRAPPER:BOOL=%{?with_linphonepp:YES}%{?!with_linphonepp:NO}
%cmake_build

%install
%cmake_install

# plugins
mkdir -p %{buildroot}%{_libdir}/%{name}/plugins

# remove unwanted docs, generated if doxygen is installed
rm -rf %{buildroot}%{_docdir}/ortp %{buildroot}%{_docdir}/mediastreamer*

%files -n linphone-cli
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_bindir}/linphonec*

%files -n linphone-daemon
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_bindir}/linphone-daemon*

%files data
%{_datadir}/sounds/linphone/
%{_datadir}/belr/grammars/*_grammar
%dir %{_datadir}/linphone/
%{_datadir}/linphone/rootca.pem

%files -n %{libname}
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_libdir}/liblinphone.so.*

%dir %{_libdir}/%{name}/plugins

%if %{with linphonepp}
%files -n %{libnamepp}
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_libdir}/liblinphone++.so.*
%endif

%files -n %{devname}
%if %{with docs}
%doc %{_docdir}/%{name}-%{version}/c/
%endif
%{_includedir}/linphone/
%{_libdir}/liblinphone.so
%{_libdir}/cmake/LibLinphone/

%if %{with linphonepp}
%if %{with docs}
%doc %{_docdir}/%{name}-%{version}/cpp/
%endif
%{_includedir}/linphone++/
%{_libdir}/liblinphone++.so
%{_libdir}/cmake/LinphoneCxx/
%endif


%changelog
* Wed Feb 19 2025 Eduard Basov <ebasov@msvsphere-os.ru> - 5.3.84-1.inferit
- Rebuild For MSVSphere 10.0

* Fri Sep 20 2024 Dmitriy Samoylik <samoylikdv@msvsphere-os.ru> - 5.3.84-1.inferit
- Update to 5.3.84-1.inferit

* Fri May 31 2024 Arkady L. Shane <tigro@msvsphere-os.ru> - 5.3.54-1.inferit
- Update to 5.3.54
- Clean up spec

* Wed May 29 2024 Sergey Cherevko <s.cherevko@msvsphere-os.ru> 5.3.5-3.inferit
- Rebuilt for MSVSphere 9.4

* Mon Jan 01 2024 wally <wally> 5.3.5-3.mga10
+ Revision: 2025363
- use system CA bundle

* Mon Jan 01 2024 wally <wally> 5.3.5-2.mga10
+ Revision: 2024993
- force jsoncpp req via cmake
- force system xsd
- drop unmaintained pkg-conf .pc files

* Sat Dec 30 2023 wally <wally> 5.3.5-1.mga10
+ Revision: 2024685
- new version 5.3.5
+ daviddavid <daviddavid>
- rebuild for new jsoncpp 1.9.5
- rebuild for new zxing-cpp 2.1.0

* Fri Jun 09 2023 wally <wally> 5.2.70-1.mga9
+ Revision: 1961537
- new version 5.2.70

* Tue Dec 27 2022 daviddavid <daviddavid> 5.2.4-4.mga9
+ Revision: 1927280
- rebuild for zxing-cpp with bumped lib major

* Sat Dec 24 2022 wally <wally> 5.2.4-3.mga9
+ Revision: 1926394
- require soci sqlite3 and mysql backends with lib

* Sat Dec 24 2022 wally <wally> 5.2.4-2.mga9
+ Revision: 1926355
- build with soci-mysql and soci-sqlite3

* Sat Dec 24 2022 wally <wally> 5.2.4-1.mga9
+ Revision: 1926335
- new version 5.2.4

* Sun Dec 04 2022 wally <wally> 5.1.72-1.mga9
+ Revision: 1917540
- new version 5.1.72
- build using ninja

* Tue Aug 23 2022 wally <wally> 5.1.56-1.mga9
+ Revision: 1879660
- new version 5.1.56

* Wed May 04 2022 wally <wally> 5.1.28-1.mga9
+ Revision: 1856193
- new version 5.1.28
- rebuild to core/release

* Tue Apr 05 2022 umeabot <umeabot> 5.0.35-2.mga9
+ Revision: 1844677
- Mageia 9 Mass Rebuild

* Sun Nov 21 2021 wally <wally> 5.0.35-1.mga9
+ Revision: 1758381
- new version 5.0.35

* Sat Jul 31 2021 wally <wally> 5.0.3-1.mga9
+ Revision: 1738418
- new version 5.0.3
- enable API docs

* Sun May 30 2021 wally <wally> 4.5.17-1.mga9
+ Revision: 1728852
- new version 4.5.17

* Mon Apr 12 2021 wally <wally> 4.5.1-1.mga9
+ Revision: 1715466
- new version 4.5.1

* Sun Dec 27 2020 wally <wally> 4.4.21-1.mga9
+ Revision: 1664169
- new version 4.4.21

* Sun Dec 20 2020 wally <wally> 4.4.19-1.mga8
+ Revision: 1661470
- new version 4.4.19

* Fri Dec 11 2020 wally <wally> 4.4.15-1.mga8
+ Revision: 1655434
- new version 4.4.15

* Thu Dec 10 2020 wally <wally> 4.4.13-1.mga8
+ Revision: 1655181
- new version 4.4.13
- new version 4.4.9

* Sun Oct 25 2020 wally <wally> 4.4.6-1.mga8
+ Revision: 1639247
- new version 4.4.6

* Sat Oct 03 2020 wally <wally> 4.4.2-1.mga8
+ Revision: 1632072
- new version 4.4.2
- new lib major 10
- enable linphonepp build

* Sat Mar 28 2020 wally <wally> 4.3.1-2.mga8
+ Revision: 1561514
- rename src pkg as liblinphone
- drop 'unused' .desktop file patch

* Sat Mar 28 2020 wally <wally> 4.3.1-1.mga8
+ Revision: 1561426
- new version 4.3.1
- disable doc and C++ wrapper build for now because of incompatible doxygen version

* Tue Feb 18 2020 umeabot <umeabot> 3.12.0-7.mga8
+ Revision: 1542184
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 3.12.0-6.mga8
+ Revision: 1475981
- rebuild for readline
+ wally <wally>
- build with new cmake macros

* Sun Sep 22 2019 daviddavid <daviddavid> 3.12.0-5.mga8
+ Revision: 1444569
- drop unneeded python2 BRs

* Mon Dec 31 2018 luigiwalser <luigiwalser> 3.12.0-4.mga7
+ Revision: 1347733
- build against libupnp 1.8
- rebuild for libupnp

* Sat Sep 08 2018 wally <wally> 3.12.0-3.mga7
+ Revision: 1257837
- disable strict compiler warnings for now

* Mon Jan 01 2018 wally <wally> 3.12.0-2.mga7
+ Revision: 1188852
- disable GTK UI and tools build
- create cli pkg for command line interface
- create noarch data pkg for sounds

* Mon Jan 01 2018 wally <wally> 3.12.0-1.mga7
+ Revision: 1188823
- new version 3.12.0
- switch to cmake build
- move liblinphone_tester to devel pkg
- create liblinphone++ pkg
- drop linphonetester lib
- rebuild for new libbctoolbox

* Tue May 02 2017 akien <akien> 3.10.2-5.mga6
+ Revision: 1098301
- Rebuild for ffmpeg 3.3

* Fri Mar 10 2017 akien <akien> 3.10.2-4.mga6
+ Revision: 1091624
- Rebuild for v4l-utils 1.12.3

* Sun Jan 22 2017 akien <akien> 3.10.2-3.mga6
+ Revision: 1083077
- Rebuild for arm

* Sun Jan 22 2017 akien <akien> 3.10.2-2.mga6
+ Revision: 1083027
- Remove BR on mbedtls, used only to build bctoolbox

* Fri Dec 02 2016 daviddavid <daviddavid> 3.10.2-1.mga6
+ Revision: 1071701
- new version: 3.10.2
- now libmajor is 9
- add a new library subpackage on liblinphonetester
- add BR pkgconfig(bctoolbox)
- pass NOCONFIGURE=1 to autogen
+ tmb <tmb>
- rebuild for new ortp
+ zezinho <zezinho>
- update BR

* Mon Jan 25 2016 luigiwalser <luigiwalser> 3.9.1-1.mga6
+ Revision: 927507
- 3.9.1

* Thu Jan 14 2016 luigiwalser <luigiwalser> 3.9.0-2.mga6
+ Revision: 923147
- rebuild for polarssl/mbedtls
+ oden <oden>
- reverty the polarssl -> mbedtls switch
- polarssl/mbedtls

* Mon Nov 16 2015 oden <oden> 3.9.0-1.mga6
+ Revision: 903601
- package all icons and cruft
- bump soname to 8
- deactivate one patch
- 3.9.0

* Sun Aug 02 2015 oden <oden> 3.8.5-1.mga6
+ Revision: 860695
- 3.8.5
- adjust deps and file lists
- break out mediastreamer

* Sat Jun 27 2015 cjw <cjw> 3.8.1-3.mga6
+ Revision: 846279
- rebuild for libvpx 1.4

* Wed Jun 24 2015 akien <akien> 3.8.1-2.mga6
+ Revision: 842281
- Rebuild for GLEW 1.12
+ alexl <alexl>
- deleted russian patch (in upstream now)

* Thu Apr 30 2015 oden <oden> 3.8.1-1.mga5
+ Revision: 820862
- 3.8.1
- rediff some patches, deactivate one weird russian one
- fix deps

* Fri Jan 16 2015 alexl <alexl> 3.7.0-1.mga5
+ Revision: 810993
- add missing requires on libmediastreamer3
- added GenericName for desktop file from upstream
- delete libav9 and exosip patches, rediff patches, add translatable.patch from upstream
- version 3.7.0 (mga#14760)

* Fri Nov 14 2014 akien <akien> 3.6.1-12.mga5
+ Revision: 797112
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 3.6.1-11.mga5
+ Revision: 747577
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.6.1-10.mga5
+ Revision: 726984
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.6.1-9.mga5
+ Revision: 681948
- Mageia 5 Mass Rebuild

* Thu Sep 11 2014 alexl <alexl> 3.6.1-8.mga5
+ Revision: 674735
- updated Russian translation

* Fri Sep 05 2014 alexl <alexl> 3.6.1-7.mga5
+ Revision: 672433
- translated desktop file

* Mon Sep 01 2014 luigiwalser <luigiwalser> 3.6.1-6.mga5
+ Revision: 670271
- rebuild for glew

* Sun Jul 06 2014 wally <wally> 3.6.1-5.mga5
+ Revision: 650129
- add patch from Sebastian Ramacher (via Debian) to fix build with new ffmpeg

* Sat Oct 19 2013 umeabot <umeabot> 3.6.1-4.mga4
+ Revision: 530647
- Mageia 4 Mass Rebuild

* Fri Jul 26 2013 sander85 <sander85> 3.6.1-3.mga4
+ Revision: 458677
- Rebuild for new glew

* Thu Jul 11 2013 fwang <fwang> 3.6.1-2.mga4
+ Revision: 452778
- rebuild for new ffmpeg

* Fri Jun 28 2013 fwang <fwang> 3.6.1-1.mga4
+ Revision: 447717
- update patch series
- update file list and libmajor
- update file list
- add patch from pld-linux to build with exosip 4.0
- br vim
- bump ortp req
- update br
- new version 3.6.1

* Sat Jan 12 2013 umeabot <umeabot> 3.5.2-5.mga3
+ Revision: 358833
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 3.5.2-4.mga3
+ Revision: 341733
- fix build with automake 1.13
- rebuild for new ffmpeg
+ luigiwalser <luigiwalser>
- BR automake

* Sat Oct 20 2012 malo <malo> 3.5.2-2.mga3
+ Revision: 308465
- update RPM group

* Fri Jun 01 2012 fwang <fwang> 3.5.2-1.mga3
+ Revision: 252815
- update file list
- more patch
- more patch
- fix build with latest ffmpeg 0.11

* Mon Mar 05 2012 fwang <fwang> 3.5.2-1.mga2
+ Revision: 218368
- update file list
- new version 3.5.2

* Fri Mar 02 2012 fwang <fwang> 3.5.0-2.mga2
+ Revision: 216670
- rebuild for new vpx

* Tue Dec 27 2011 fwang <fwang> 3.5.0-1.mga2
+ Revision: 188087
- use external ortp
- update file list
- update file list
- fix linkage
- new version 3.5.0
- rebuild for new exosip

* Fri Jun 24 2011 fwang <fwang> 3.4.3-1.mga2
+ Revision: 113126
- new version 3.4.3

* Thu Jan 20 2011 ahmad <ahmad> 3.3.2-2.mga1
+ Revision: 27055
- imported package linphone

